BuildLog

Struct BuildLog 

pub struct BuildLog<'a> { /* private fields */ }
Store a log of every command ran for every build. It has a few uses:

  1. (hashes of) command lines for existing output files, so we know when we need to rebuild due to the command changing
  2. timing information, perhaps for generating reports
  3. restat information

Implementations

Source

impl<'a> BuildLog<'a>

pub fn new() -> Self

pub fn open_for_write<User: BuildLogUser>( &self, path: &Path, user: &User, ) -> Result<(), String>

pub fn record_command_without_timestamp( &self, state: &State, edge_idx: EdgeIndex, start_time: u64, end_time: u64, ) -> Result<(), ()>

pub fn record_command( &self, state: &State, edge_idx: EdgeIndex, start_time: u64, end_time: u64, mtime: TimeStamp, ) -> Result<(), ()>

pub fn close(&mut self)

pub fn load(&mut self, path: &Path) -> Result<Option<String>, String>

Load the on-disk log.

pub fn lookup_by_output(&self, path: &[u8]) -> Option<&BuildLogEntry>

Lookup a previously-run command by its output path.

pub fn write_entry<W: Write>( &self, f: &W, entry: &BuildLogEntry, ) -> Result<(), ()>

Serialize an entry into a log file.

pub fn recompact<User: BuildLogUser>( &self, path: &Path, user: &User, ) -> Result<(), String>

Rewrite the known log entries, throwing away old data.

pub fn entries(&'a self) -> &'a HashMap<&'a str, &'a BuildLogEntry>