Subprocess

Struct Subprocess 

pub struct Subprocess { /* private fields */ }
Subprocess wraps a single async subprocess. It is entirely passive: it expects the caller to notify it when its fds are ready for reading, as well as call Finish() to reap the child once done() is true.

Implementations

Source

impl Subprocess

pub fn output(&self) -> &[u8]

Source

impl Subprocess

pub fn on_pipe_ready(&mut self)

pub fn finish(&mut self) -> ExitStatus

Returns ExitSuccess on successful process exit, ExitInterrupted if the process was interrupted, ExitFailure if it otherwise failed.