DependencyScan

Struct DependencyScan 

pub struct DependencyScan<'s, 'a, 'b, 'c>
where 's: 'a,
{ /* private fields */ }
DependencyScan manages the process of scanning the files in a graph and updating the dirty/outputs_ready state of all the nodes and edges.

Implementations

Source

impl<'s, 'a, 'b, 'c> DependencyScan<'s, 'a, 'b, 'c>
where 's: 'a,

pub fn new( build_log: &'a BuildLog<'s>, deps_log: &'b DepsLog, disk_interface: &'c dyn DiskInterface, ) -> Self

pub fn build_log(&self) -> Option<&'a BuildLog<'s>>

pub fn deps_log(&self) -> &'b DepsLog

pub fn recompute_dirty( &self, state: &mut State, node_idx: NodeIndex, ) -> Result<(), String>

Update the |dirty_| state of the given node by inspecting its input edge. Examine inputs, outputs, and command lines to judge whether an edge needs to be re-run, and update outputs_ready_ and each outputs’ |dirty_| state accordingly. Returns false on failure.