pub struct State {
pub node_state: NodeState,
pub edge_state: EdgeState,
pub pool_state: PoolState,
pub bindings: Rc<RefCell<BindingEnv>>,
/* private fields */
}Expand description
Global state (file status) for a single run.
Fields
node_state: NodeStateedge_state: EdgeStatepool_state: PoolStatebindings: Rc<RefCell<BindingEnv>>Implementations
Sourceimpl State
impl State
pub fn new() -> Self
pub fn connect_edge_to_in_node( edge: &mut Edge, edge_idx: EdgeIndex, node: &mut Node, node_idx: NodeIndex, )
pub fn connect_edge_to_out_node( edge: &mut Edge, edge_idx: EdgeIndex, node: &mut Node, node_idx: NodeIndex, ) -> bool
pub fn get_env(&self) -> Rc<RefCell<BindingEnv>>
pub fn add_default(&mut self, path: &[u8]) -> Result<(), String>
Sourcepub fn root_nodes(&self) -> Result<Vec<NodeIndex>, String>
pub fn root_nodes(&self) -> Result<Vec<NodeIndex>, String>
@return the root node(s) of the graph. (Root nodes have no output edges). @param error where to write the error message if somethings went wrong.
pub fn default_nodes(&self) -> Result<Vec<NodeIndex>, String>
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Reset state. Keeps all nodes and edges, but restores them to the state where we haven’t yet examined the disk for dirty state.
pub fn spellcheck_node(&self, path: &[u8]) -> Option<&[u8]>