pub struct Subprocess { /* private fields */ }Expand description
Subprocess wraps a single async subprocess. It is entirely passive: it expects the caller to notify it when its fds are ready for reading, as well as call Finish() to reap the child once done() is true.
Implementations
Sourceimpl Subprocess
impl Subprocess
pub fn on_pipe_ready(&mut self)
Sourcepub fn finish(&mut self) -> ExitStatus
pub fn finish(&mut self) -> ExitStatus
Returns ExitSuccess on successful process exit, ExitInterrupted if the process was interrupted, ExitFailure if it otherwise failed.